/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

/*
 * Do not modify this file. This file is generated from the ssm-2014-11-06.normal.json service model.
 */
using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.Text;
using System.IO;

using Amazon.Runtime;
using Amazon.Runtime.Internal;

namespace Amazon.SimpleSystemsManagement.Model
{
    /// <summary>
    /// Container for the parameters to the DescribeInstanceInformation operation.
    /// Describes one or more of your instances. You can use this to get information about
    /// instances like the operating system platform, the SSM agent version, status etc. If
    /// you specify one or more instance IDs, it returns information for those instances.
    /// If you do not specify instance IDs, it returns information for all your instances.
    /// If you specify an instance ID that is not valid or an instance that you do not own,
    /// you receive an error.
    /// </summary>
    public partial class DescribeInstanceInformationRequest : AmazonSimpleSystemsManagementRequest
    {
        private List<InstanceInformationFilter> _instanceInformationFilterList = new List<InstanceInformationFilter>();
        private int? _maxResults;
        private string _nextToken;

        /// <summary>
        /// Gets and sets the property InstanceInformationFilterList. One or more filters. Use
        /// a filter to return a more specific list of instances.
        /// </summary>
        public List<InstanceInformationFilter> InstanceInformationFilterList
        {
            get { return this._instanceInformationFilterList; }
            set { this._instanceInformationFilterList = value; }
        }

        // Check to see if InstanceInformationFilterList property is set
        internal bool IsSetInstanceInformationFilterList()
        {
            return this._instanceInformationFilterList != null && this._instanceInformationFilterList.Count > 0; 
        }

        /// <summary>
        /// Gets and sets the property MaxResults. The maximum number of items to return for this
        /// call. The call also returns a token that you can specify in a subsequent call to get
        /// the next set of results.
        /// </summary>
        public int MaxResults
        {
            get { return this._maxResults.GetValueOrDefault(); }
            set { this._maxResults = value; }
        }

        // Check to see if MaxResults property is set
        internal bool IsSetMaxResults()
        {
            return this._maxResults.HasValue; 
        }

        /// <summary>
        /// Gets and sets the property NextToken. The token for the next set of items to return.
        /// (You received this token from a previous call.)
        /// </summary>
        public string NextToken
        {
            get { return this._nextToken; }
            set { this._nextToken = value; }
        }

        // Check to see if NextToken property is set
        internal bool IsSetNextToken()
        {
            return this._nextToken != null;
        }

    }
}